==> 0.10.1.tar.gz: lib/coupons_module/coupondetailpage.dart <==
import 'dart:convert';



import 'package:barcode_widget/barcode_widget.dart';
import 'package:flutter/material.dart';
import 'package:loyalty_management_tool/utils/locator.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../NetworkFile/calls.dart';
import '../models/buycoupon.dart';
import '../models/couponlisting.dart';
import '../utils/appProgressButton.dart';
import '../utils/basicInfo.dart';
import '../utils/colors.dart';
import '../utils/custom_app_bar.dart';
import '../utils/customcard.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';
import '../utils/toast_builder.dart';
import '../utils/utility_class.dart';
import 'couponlistitem.dart';

// ignore: must_be_immutable
class CouponDetailPage extends StatefulWidget {
  CouponListItem couponData;
  bool showQr;
  bool isGift;


  CouponDetailPage({required this.couponData, required this.showQr,this.isGift=false});

  @override
  _CouponDetailPage createState() =>
      _CouponDetailPage(couponData: couponData, showQr: showQr);
}

class _CouponDetailPage extends State<CouponDetailPage> {
  CouponListItem ?couponData;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();
  BasicInfo? basicInfo = BasicInfo();
  bool showQr;
  List<String> listPoints = [];
  late TextStyleElements styleElements;
  GlobalKey<appProgressButtonState> progressButtonKey = GlobalKey();


  _CouponDetailPage({required this.couponData, required this.showQr});

  // @override
  // void initState() {
  //   super.initState();
  //   // styleElements = TextStyleElements(context);
  //   // pr = ToastBuilder().setProgressDialog(context);
  //   // WidgetsBinding.instance.addPostFrameCallback((_) => fetchDetails());
  // }
  // void fetchDetails() async {
  //   pr = ToastBuilder().setProgressDialog(context);
  //   await pr.show();
  //   prefs = await SharedPreferences.getInstance();
  //   CouponDetailRequest payload = CouponDetailRequest();
  //   payload.id = couponId.toString();
  //   var data = jsonEncode(payload);
  //   Calls().call(data, context, Config.COUPON_DETAIL).then((value) {
  //     await pr.hide();
  //     var res = CouponDetailResponse.fromJson(value);
  //     if (res.statusCode == Strings.success_code) {
  //       setState(() {
  //         item = res.rows;
  //         if (item.couponTermsConditionsPoints != null &&
  //             item.couponTermsConditionsPoints.length > 0) {
  //           listPoints = item.couponTermsConditionsPoints;
  //         }
  //       });
  //     }
  //   }).catchError((onError) {
  //     await pr.hide();
  //     print(onError);
  //   });
  // }



  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    return SafeArea(
      child: Scaffold(
        appBar: appAppBar().getCustomAppBar(context, appBarTitle: widget.isGift?'Gift card detail':'Coupon detail', onBackButtonPress: (){Navigator.pop(context);}),
        body: appListCard(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Container(
                padding: EdgeInsets.all(4),
                child: CouponListItemCard(
                  imageWidth: 92,
                  imageHeight: 92,
                  title: couponData != null ? couponData!.couponProvider : "",
                  imageUrl: couponData != null ? couponData!.couponImage : "",
                  discount: couponData != null ? couponData!.couponDiscount : 0,
                  discountType: couponData != null ? couponData!.couponDiscountType : "",
                  rewardPoints: couponData != null ? couponData!.rewardPointsRequired : 0,
                  validTill: Utility().getDateFormat(
                      basicInfo!.dateFormat,
                      // ignore: unnecessary_null_comparison
                      couponData != null
                          ? DateTime.parse(couponData!.validTill!)
                          : DateTime.now()),
                  isDividerHide: true,
                  isActive: false,
                  isCoinsHide: true,
                ),
              ),
              Container(
                margin: EdgeInsets.only(top: 24, left: 48, right: 48),
                child: Text(
                  (couponData!.couponTermsConditionsHeading != null)
                      ? couponData!.couponTermsConditionsHeading!
                      : "Terms and Conditions",
                  textAlign: TextAlign.center,
                  style:  styleElements.headline6ThemeScalable(context),
                ),
              ),
              Visibility(
                visible: couponData!.couponTermsConditionsPoints!.length > 0,
                child: Container(
                  child: ListView.builder(
                    shrinkWrap: true,
                      padding:
                          EdgeInsets.only(left: 8, right: 8, bottom: 8, top: 8),
                      itemCount: couponData!.couponTermsConditionsPoints!.length,
                      itemBuilder: (BuildContext context, int index) {
                        return Row(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Container(
                              margin:
                                  EdgeInsets.only(top: 8, left: 16, right: 16),
                              width: 6,
                              height: 6,
                              decoration: BoxDecoration(
                                color: HexColor(AppColors.appColorBlack65),
                                shape: BoxShape.circle,
                              ),
                            ),
                            Flexible(
                              child: Text(
                                couponData!.couponTermsConditionsPoints![index],
                                style:  styleElements.bodyText2ThemeScalable(context),
                              ),
                            ),
                          ],
                        );
                      }),
                ),
              ),
              Spacer(),
              Container(
                  margin: EdgeInsets.only(top: 100, bottom: 40),
                  child: getBottomWidgets())
            ],
          ),
        ),
      ),
    );
  }

  Widget getBottomWidgets() => Stack(
        children: [
          Visibility(
            visible: !showQr,
            child: appProgressButton(
              key: progressButtonKey,
              child: Text(
                getButtonText(),
                style: styleElements
                    .headline6ThemeScalableW(context)
                    .copyWith(
                    color:
                    HexColor(AppColors.appColorWhite)),),
              onPressed: () {
                purchaseCoupon();
              },
              shape: StadiumBorder(),
              color: HexColor(AppColors.appMainColor),
              splashColor: HexColor(AppColors.appMainColor),
              padding: EdgeInsets.only(left: 56, right: 56, top: 16, bottom: 16),
            ),
          ),
          Visibility(
            visible: showQr,
            child:
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: BarcodeWidget(
                barcode: Barcode.code128(),
                data: (couponData != null&&couponData!.qrCode!=null) ? couponData!.qrCode! : "a",
                height: 90,
                drawText: true,
              ),
            )

          ),
        ],
      );


  String getButtonText() {
    // ignore: unnecessary_null_comparison
    if (couponData != null) {
      String coins = couponData!.rewardPointsRequired.toString();
      return "Redeem @$coins coins";
    } else {
      return "";
    }
  }

  void purchaseCoupon() async{
    prefs= await SharedPreferences.getInstance();
   progressButtonKey.currentState!.show();
    PurchaseCouponRequest payload = PurchaseCouponRequest();
    payload.personId =  basicInfo!.userId.toString();
    payload.allCouponsId = couponData!.id.toString();
    payload.purchaseDatetime = DateTime.now().millisecondsSinceEpoch.toString();
    var data = jsonEncode(payload);
    Calls().call(data, context, basicInfo!.couponPurchase).then((value) async {
      progressButtonKey.currentState!.hide();
      var res = PurchaseCouponResponse.fromJson(value);
      if (res.statusCode == basicInfo!.statusCode) {
        Navigator.pop(context);
        ToastBuilder().showToast(res.message!, context,HexColor(AppColors.information));
        // setState(() {
        //   showQr = true;
        // });
        // fetchDetails();
      } else {
        ToastBuilder().showToast(res.message!, context,HexColor(AppColors.information));
      }
    }).catchError((onError) async {
      progressButtonKey.currentState!.hide();
      print(onError);
    });
  }
}

==> 0.11.1.tar.gz: lib/coupons_module/coupondetailpage.dart <==
import 'dart:convert';

import 'package:barcode_widget/barcode_widget.dart';
import 'package:flutter/material.dart';
import 'package:loyalty_management_tool/utils/locator.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../NetworkFile/calls.dart';
import '../models/buycoupon.dart';
import '../models/couponlisting.dart';
import '../utils/appProgressButton.dart';
import '../utils/basicInfo.dart';
import '../utils/colors.dart';
import '../utils/custom_app_bar.dart';
import '../utils/customcard.dart';
import '../utils/hexColors.dart';
import '../utils/text_styling.dart';
import '../utils/toast_builder.dart';
import '../utils/utility_class.dart';
import 'couponlistitem.dart';

// ignore: must_be_immutable
class CouponDetailPage extends StatefulWidget {
  CouponListItem couponData;
  bool showQr;
  bool isGift;

  CouponDetailPage(
      {required this.couponData, required this.showQr, this.isGift = false});

  @override
  _CouponDetailPage createState() =>
      _CouponDetailPage(couponData: couponData, showQr: showQr);
}

class _CouponDetailPage extends State<CouponDetailPage> {
  CouponListItem? couponData;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();
  BasicInfo? basicInfo = BasicInfo();
  bool showQr;
  List<String> listPoints = [];
  late TextStyleElements styleElements;
  GlobalKey<appProgressButtonState> progressButtonKey = GlobalKey();

  _CouponDetailPage({required this.couponData, required this.showQr});

  // @override
  // void initState() {
  //   super.initState();
  //   // styleElements = TextStyleElements(context);
  //   // pr = ToastBuilder().setProgressDialog(context);
  //   // WidgetsBinding.instance.addPostFrameCallback((_) => fetchDetails());
  // }
  // void fetchDetails() async {
  //   pr = ToastBuilder().setProgressDialog(context);
  //   await pr.show();
  //   prefs = await SharedPreferences.getInstance();
  //   CouponDetailRequest payload = CouponDetailRequest();
  //   payload.id = couponId.toString();
  //   var data = jsonEncode(payload);
  //   Calls().call(data, context, Config.COUPON_DETAIL).then((value) {
  //     await pr.hide();
  //     var res = CouponDetailResponse.fromJson(value);
  //     if (res.statusCode == Strings.success_code) {
  //       setState(() {
  //         item = res.rows;
  //         if (item.couponTermsConditionsPoints != null &&
  //             item.couponTermsConditionsPoints.length > 0) {
  //           listPoints = item.couponTermsConditionsPoints;
  //         }
  //       });
  //     }
  //   }).catchError((onError) {
  //     await pr.hide();
  //     print(onError);
  //   });
  // }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    return SafeArea(
      child: Scaffold(
        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle: widget.isGift ? 'Gift card detail' : 'Coupon detail',
            onBackButtonPress: () {
          Navigator.pop(context);
        }),
        body: appListCard(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: [
              Container(
                padding: EdgeInsets.all(4),
                child: CouponListItemCard(
                  imageWidth: 92,
                  imageHeight: 92,
                  title: couponData != null ? couponData!.couponProvider : "",
                  imageUrl: couponData != null ? couponData!.couponImage : "",
                  discount: couponData != null ? couponData!.couponDiscount : 0,
                  discountType:
                      couponData != null ? couponData!.couponDiscountType : "",
                  rewardPoints:
                      couponData != null ? couponData!.rewardPointsRequired : 0,
                  validTill: Utility().getDateFormat(
                      basicInfo!.dateFormat,
                      // ignore: unnecessary_null_comparison
                      couponData != null
                          ? DateTime.parse(couponData!.validTill!)
                          : DateTime.now()),
                  isDividerHide: true,
                  isActive: false,
                  isCoinsHide: true,
                ),
              ),
              Container(
                margin: EdgeInsets.only(top: 24, left: 48, right: 48),
                child: Text(
                  (couponData!.couponTermsConditionsHeading != null)
                      ? couponData!.couponTermsConditionsHeading!
                      : "Terms and Conditions",
                  textAlign: TextAlign.center,
                  style: styleElements.headline6ThemeScalable(context),
                ),
              ),
              Visibility(
                visible: couponData!.couponTermsConditionsPoints!.length > 0,
                child: Container(
                  child: ListView.builder(
                      shrinkWrap: true,
                      padding:
                          EdgeInsets.only(left: 8, right: 8, bottom: 8, top: 8),
                      itemCount:
                          couponData!.couponTermsConditionsPoints!.length,
                      itemBuilder: (BuildContext context, int index) {
                        return Row(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Container(
                              margin:
                                  EdgeInsets.only(top: 8, left: 16, right: 16),
                              width: 6,
                              height: 6,
                              decoration: BoxDecoration(
                                color: HexColor(AppColors.appColorBlack65),
                                shape: BoxShape.circle,
                              ),
                            ),
                            Flexible(
                              child: Text(
                                couponData!.couponTermsConditionsPoints![index],
                                style: styleElements
                                    .bodyText2ThemeScalable(context),
                              ),
                            ),
                          ],
                        );
                      }),
                ),
              ),
              Spacer(),
              Container(
                  margin: EdgeInsets.only(top: 100, bottom: 40),
                  child: getBottomWidgets())
            ],
          ),
        ),
      ),
    );
  }

  Widget getBottomWidgets() => Stack(
        children: [
          Visibility(
            visible: !showQr,
            child: appProgressButton(
              key: progressButtonKey,
              child: Text(
                getButtonText(),
                style: styleElements
                    .headline6ThemeScalableW(context)
                    .copyWith(color: HexColor(AppColors.appColorWhite)),
              ),
              onPressed: () {
                purchaseCoupon();
              },
              shape: StadiumBorder(),
              color: HexColor(AppColors.appMainColor),
              splashColor: HexColor(AppColors.appMainColor),
              padding:
                  EdgeInsets.only(left: 56, right: 56, top: 16, bottom: 16),
            ),
          ),
          Visibility(
              visible: showQr,
              child: Padding(
                padding: const EdgeInsets.all(8.0),
                child: BarcodeWidget(
                  barcode: Barcode.code128(),
                  data: (couponData != null && couponData!.qrCode != null)
                      ? couponData!.qrCode!
                      : "a",
                  height: 90,
                  drawText: true,
                ),
              )),
        ],
      );

  String getButtonText() {
    // ignore: unnecessary_null_comparison
    if (couponData != null) {
      String coins = couponData!.rewardPointsRequired.toString();
      return "Redeem @$coins coins";
    } else {
      return "";
    }
  }

  void purchaseCoupon() async {
    prefs = await SharedPreferences.getInstance();
    progressButtonKey.currentState!.show();
    PurchaseCouponRequest payload = PurchaseCouponRequest();
    payload.personId = basicInfo!.userId.toString();
    payload.allCouponsId = couponData!.id.toString();
    payload.purchaseDatetime = DateTime.now().millisecondsSinceEpoch.toString();
    var data = jsonEncode(payload);
    Calls().call(data, context, basicInfo!.couponPurchase).then((value) async {
      progressButtonKey.currentState!.hide();
      var res = PurchaseCouponResponse.fromJson(value);
      if (res.statusCode == basicInfo!.statusCode) {
        Navigator.pop(context);
        ToastBuilder()
            .showToast(res.message!, context, HexColor(AppColors.information));
        // setState(() {
        //   showQr = true;
        // });
        // fetchDetails();
      } else {
        ToastBuilder()
            .showToast(res.message!, context, HexColor(AppColors.information));
      }
    }).catchError((onError) async {
      progressButtonKey.currentState!.hide();
      print(onError);
    });
  }
}
